package de.jottyfan.timetrack.modules;

import static de.jottyfan.timetrack.db.profile.Tables.T_LOGIN;

import java.sql.SQLException;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jooq.DSLContext;
import org.jooq.Record4;
import org.jooq.SelectConditionStep;
import org.jooq.exception.DataAccessException;

import de.jooqFaces.JooqFacesContext;

/**
 * 
 * @author henkej
 *
 */
public class SessionGateway extends JooqGateway {
	private static final Logger LOGGER = LogManager.getLogger();

	public SessionGateway(JooqFacesContext facesContext) {
		super(facesContext);
	}

	/**
	 * seek login and set bean's login to that; if not found, return false
	 * 
	 * @param bean
	 *          the bean
	 * @return true or false
	 * @throws SQLException 
	 * @throws ClassNotFoundException 
	 * @throws DataAccessException 
	 */
	public boolean seekAndSetLogin(SessionBean bean) throws DataAccessException, ClassNotFoundException, SQLException {
		try (DSLContext jooq = getJooq()) {
			SelectConditionStep<Record4<Integer, String, String, String>> sql = jooq
			// @formatter:off
				.select(T_LOGIN.PK,
						    T_LOGIN.FORENAME,
						    T_LOGIN.SURNAME,
						    T_LOGIN.PASSWORD)
				.from(T_LOGIN)
				.where(T_LOGIN.LOGIN.eq(bean.getUsername()));
			// @formatter:on
			LOGGER.debug(sql.toString());
			Record4<Integer, String, String, String> r = sql.fetchOne();
			if (r != null) {
				String encrypted = r.get(T_LOGIN.PASSWORD);
				if (bean.checkSecret(encrypted)) {
					bean.setLogin(r.get(T_LOGIN.PK));
					bean.setForename(r.get(T_LOGIN.FORENAME));
					bean.setSurname(r.get(T_LOGIN.SURNAME));
					return true;
				} else {
					throw new DataAccessException("wrong password");
				}
			} else {
				return false;
			}
		}
	}

}
