package de.jottyfan.timetrack.modules.contact;

import java.io.Serializable;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.enterprise.context.SessionScoped;
import javax.faces.application.FacesMessage;
import javax.inject.Named;

import org.jooq.exception.DataAccessException;

import de.jooqFaces.JooqFacesContext;
import de.jottyfan.timetrack.db.contact.enums.EnumContacttype;
import de.jottyfan.timetrack.modules.Model;

/**
 * 
 * @author jotty
 *
 */
@Named
@SessionScoped
public class ContactModel implements Model, Serializable {
	private static final long serialVersionUID = 1L;

	private ContactBean bean;
	private List<ContactBean> list;
	private List<EnumContacttype> types;

	public boolean init(JooqFacesContext facesContext) {
		bean = new ContactBean(null);
		try {
			ContactGateway gw = new ContactGateway(facesContext);
			list = gw.getAll();
			types = gw.getTypes();
			return true;
		} catch (DataAccessException | ClassNotFoundException | SQLException e) {
			facesContext.addMessage(null,
					new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on loading data from db", e.getMessage()));
			list = new ArrayList<>();
			types = new ArrayList<>();
			return false;
		}
	}

	public boolean delete(JooqFacesContext facesContext) {
		try {
			Integer affected = new ContactGateway(facesContext).delete(bean.getPk());
			return affected.equals(1);
		} catch (DataAccessException | ClassNotFoundException | SQLException e) {
			facesContext.addMessage(null,
					new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on deleting data from db", e.getMessage()));
			return false;
		}
	}

	public boolean add(JooqFacesContext facesContext) {
		try {
			Integer affected = new ContactGateway(facesContext).add(bean);
			return affected.equals(1);
		} catch (DataAccessException | ClassNotFoundException | SQLException e) {
			facesContext.addMessage(null,
					new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on adding data to db", e.getMessage()));
			return false;
		}
	}

	public boolean update(JooqFacesContext facesContext) {
		try {
			Integer affected = new ContactGateway(facesContext).update(bean);
			return affected.equals(1);
		} catch (DataAccessException | ClassNotFoundException | SQLException e) {
			facesContext.addMessage(null,
					new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on updating data to db", e.getMessage()));
			return false;
		}
	}

	public Integer getAmount(JooqFacesContext facesContext) {
		try {
			return new ContactGateway(facesContext).getAmount();
		} catch (DataAccessException | ClassNotFoundException | SQLException e) {
			facesContext.addMessage(null,
					new FacesMessage(FacesMessage.SEVERITY_ERROR, "error on getting size of contacts", e.getMessage()));
			return -1;
		}
	}

	public List<ContactBean> getList() {
		return list;
	}

	public void setBean(ContactBean bean) {
		this.bean = bean;
	}

	@Override
	public ContactBean getBean() {
		return bean;
	}

	public List<EnumContacttype> getTypes() {
		return types;
	}

	public void setTypes(List<EnumContacttype> types) {
		this.types = types;
	}
}
