package de.jottyfan.timetrack.modules.done;

import java.io.Serializable;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;

import javax.enterprise.context.RequestScoped;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;

import de.jooqFaces.JooqFacesContext;
import de.jottyfan.timetrack.help.Navigation;
import de.jottyfan.timetrack.help.Pages;
import de.jottyfan.timetrack.modules.ControlInterface;

/**
 * 
 * @author henkej
 * 
 */
@Named
@RequestScoped
public class DoneControl extends Navigation implements ControlInterface, Serializable {
	private static final long serialVersionUID = 1L;

	@Inject
	@Named("doneModel")
	private DoneModel model;

	public String toStart() {
		return navigateTo(Pages.START);
	}

	public String toList() {
		boolean ready = model.init((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_INIT) : toStart();
	}

	public String toAdd() {
		DoneBean bean = new DoneBean();
		bean.setTimeFrom(getCurrentDate());
		model.setBean(bean);
		boolean ready = model.loadDefaults((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_ADD) : toList();
	}

	public String toEdit(DoneBean bean) {
		model.setBean(bean);
		boolean ready = model.loadDefaults((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_EDIT) : toList();
	}

	public String toDelete(DoneBean bean) {
		model.setBean(bean);
		return navigateTo(Pages.DONE_DELETE);
	}

	public String doUpdate() {
		boolean ready = model.update((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? toList() : toEdit(model.getBean());
	}

	public String doDelete() {
		boolean ready = model.delete((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? toList() : toDelete(model.getBean());
	}

	public String doAdd() {
		boolean ready = model.insert((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? toList() : toAdd();
	}

	public String getCurrentTimeAsString() {
		return new SimpleDateFormat("HH:mm:ss").format(getCurrentDate());
	}

	public Timestamp getCurrentDate() {
		return Timestamp.valueOf(LocalDateTime.now());
	}
}
