package de.jottyfan.timetrack.modules.note;

import static de.jottyfan.timetrack.db.note.Tables.T_NOTE;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jooq.DSLContext;
import org.jooq.DeleteConditionStep;
import org.jooq.InsertValuesStep4;
import org.jooq.Record;
import org.jooq.SelectJoinStep;
import org.jooq.UpdateConditionStep;
import org.jooq.exception.DataAccessException;

import de.jooqFaces.JooqFacesContext;
import de.jottyfan.timetrack.db.note.enums.EnumCategory;
import de.jottyfan.timetrack.db.note.enums.EnumNotetype;
import de.jottyfan.timetrack.db.note.tables.records.TNoteRecord;
import de.jottyfan.timetrack.modules.JooqGateway;

/**
 * 
 * @author henkej
 *
 */
public class NoteGateway extends JooqGateway {
	private static final Logger LOGGER = LogManager.getLogger(NoteGateway.class);

	public NoteGateway(JooqFacesContext facesContext) {
		super(facesContext);
	}

	/**
	 * insert into t_note
	 * 
	 * @param noteBean
	 * @throws DataAccessException
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 * @returns amount of affected rows in db
	 */
	public void insert(NoteBean bean) throws DataAccessException, ClassNotFoundException, SQLException {
		try (DSLContext jooq = getJooq()) {
			InsertValuesStep4<TNoteRecord, String, EnumCategory, EnumNotetype, String> sql = jooq
			// @formatter:off
				.insertInto(T_NOTE, 
										T_NOTE.TITLE, 
										T_NOTE.CATEGORY, 
										T_NOTE.NOTETYPE, 
										T_NOTE.CONTENT)
				.values(bean.getTitle(), bean.getCategory(), bean.getType(), bean.getContent());
		  // @formatter:on
			LOGGER.debug(sql.toString());
			sql.execute();
		}
	}

	/**
	 * update content of bean
	 * 
	 * @param bean
	 * @throws DataAccessException
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 */
	public void update(NoteBean bean) throws DataAccessException, ClassNotFoundException, SQLException {
		try (DSLContext jooq = getJooq()) {
			UpdateConditionStep<TNoteRecord> sql = jooq
			// @formatter:off
				.update(T_NOTE)
				.set(T_NOTE.TITLE, bean.getTitle())
				.set(T_NOTE.CONTENT, bean.getContent())
				.where(T_NOTE.PK.eq(bean.getPk()));
			// @formatter:on
			LOGGER.debug(sql.toString());
			sql.execute();
		}
	}

	/**
	 * delete from t_note
	 * 
	 * @param pk
	 * @throws DataAccessException
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 */
	public void delete(Integer pk) throws DataAccessException, ClassNotFoundException, SQLException {
		try (DSLContext jooq = getJooq()) {
			DeleteConditionStep<TNoteRecord> sql = jooq.deleteFrom(T_NOTE).where(T_NOTE.PK.eq(pk));
			LOGGER.debug(sql.toString());
			sql.execute();
		}
	}

	/**
	 * get all from t_note
	 * 
	 * @return
	 * @throws DataAccessException
	 * @throws SQLException 
	 * @throws ClassNotFoundException 
	 */
	public List<NoteBean> getAll() throws DataAccessException, ClassNotFoundException, SQLException {
		try (DSLContext jooq = getJooq()) {
			SelectJoinStep<Record> sql = jooq.select().from(T_NOTE);
			LOGGER.debug(sql.toString());
			List<NoteBean> list = new ArrayList<>();
			for (Record r : sql.fetch()) {
				NoteBean bean = new NoteBean(r.get(T_NOTE.PK));
				bean.setTitle(r.get(T_NOTE.TITLE));
				bean.setCategory(r.get(T_NOTE.CATEGORY));
				bean.setContent(r.get(T_NOTE.CONTENT));
				bean.setType(r.get(T_NOTE.NOTETYPE));
				bean.setLastchange(r.get(T_NOTE.LASTCHANGE));
				list.add(bean);
			}
			return list;
		}
	}
}
