package de.jottyfan.timetrack.modules.note;

import java.io.Serializable;
import java.sql.SQLException;
import java.util.List;

import javax.enterprise.context.SessionScoped;
import javax.faces.application.FacesMessage;
import javax.inject.Named;

import org.jooq.exception.DataAccessException;

import de.jooqFaces.JooqFacesContext;
import de.jottyfan.timetrack.db.note.Tables;
import de.jottyfan.timetrack.modules.Model;

/**
 * 
 * @author henkej
 *
 */
@Named
@SessionScoped
public class NoteModel implements Model, Serializable
{
	private static final long serialVersionUID = 1L;

	private List<NoteBean> beans;
	private NoteBean bean;

	public boolean init(JooqFacesContext facesContext)
	{
		try
		{
			beans = new NoteGateway(facesContext).getAll();
			return true;
		}
		catch (DataAccessException | ClassNotFoundException | SQLException e)
		{
			facesContext.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, "error", e.getMessage()));
			return false;
		}
	}

	public boolean add(JooqFacesContext facesContext)
	{
		try
		{
			new NoteGateway(facesContext).insert(bean);
			return true;
		}
		catch (DataAccessException | ClassNotFoundException | SQLException e)
		{
			facesContext.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, "error", e.getMessage()));
			return false;
		}
	}

	public boolean update(JooqFacesContext facesContext)
	{
		try
		{
			new NoteGateway(facesContext).update(bean);
			return true;
		}
		catch (DataAccessException | ClassNotFoundException | SQLException e)
		{
			facesContext.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, "error", e.getMessage()));
			return false;
		}
	}

	public boolean delete(JooqFacesContext facesContext)
	{
		try
		{
			new NoteGateway(facesContext).delete(bean.getPk());
			return true;
		}
		catch (DataAccessException | ClassNotFoundException | SQLException e)
		{
			facesContext.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, "error", e.getMessage()));
			return false;
		}
	}
	
	public Long getAmount(JooqFacesContext facesContext)
	{
		try {
			return new NoteGateway(facesContext).getAmount(Tables.T_NOTE);
		} catch (ClassNotFoundException | SQLException e) {
			facesContext.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, "error", e.getMessage()));
			return -1l;
		}
	}
	
	@Override
	public NoteBean getBean()
	{
		return bean;
	}
	
	public void setBean(NoteBean bean)
	{
		this.bean = bean;
	}

	public List<NoteBean> getBeans()
	{
		return beans;
	}
}
