package de.jottyfan.timetrack.moduls.done;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;

import org.junit.jupiter.api.Test;

import de.jottyfan.timetrack.modules.done.DoneBean;

/**
 * 
 * @author henkej
 *
 */
public class TestDoneBean {

	@Test
	public void testGetLocalDateTimeFromHHmm() {
		LocalDateTime ldt = LocalDateTime.now();
		ldt = ldt.withSecond(0).withNano(0);
		assertEquals(ldt.withHour(0).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("0:0"));
		assertEquals(ldt.withHour(0).withMinute(5), new DoneBean().getLocalDateTimeFromHHmm("0:5"));
		assertEquals(ldt.withHour(3).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("3:2"));
		assertEquals(ldt.withHour(3).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("03:2"));
		assertEquals(ldt.withHour(10).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("10:2"));
		assertEquals(ldt.withHour(12).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("12:02"));
		assertEquals(ldt.withHour(12).withMinute(20), new DoneBean().getLocalDateTimeFromHHmm("12:20"));
		assertEquals(null, new DoneBean().getLocalDateTimeFromHHmm(null));
		assertEquals(null, new DoneBean().getLocalDateTimeFromHHmm(""));
		assertEquals(null, new DoneBean().getLocalDateTimeFromHHmm("  "));
		assertEquals(ldt.withHour(0).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("0"));
		assertEquals(ldt.withHour(1).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("1"));
		assertEquals(ldt.withHour(5).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("5"));
	}
	
	@Test
	public void testSetDay() throws ParseException {
		String today = new SimpleDateFormat("dd.MM.yyyy").format(new Date());
		SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy HH:mm");
		SimpleDateFormat sd = new SimpleDateFormat("dd.MM.yyyy");
		
		DoneBean bean = new DoneBean();
		bean.setDay(new Date());
		assertNull(bean.getTimeFrom());
		assertNull(bean.getTimeUntil());

		bean.setTimeFromString("08:00");
		Timestamp ts1 = bean.getTimeFrom();
		assertEquals(today.concat(" 08:00"), sdf.format(ts1));
		bean.setDay(sd.parse("01.01.2001"));
		assertEquals("01.01.2001", sd.format(bean.getTimeFrom()));
		assertNull(bean.getTimeUntil());

		bean.setTimeUntilString("10:00");
		Timestamp ts2 = bean.getTimeUntil();
		assertEquals(today.concat(" 10:00"), sdf.format(ts2));
		bean.setDay(sd.parse("01.01.2001"));
		assertEquals("01.01.2001", sd.format(bean.getTimeFrom()));
		assertEquals("01.01.2001", sd.format(bean.getTimeUntil()));
	}
}
